@@ -175,7 +175,39 @@ PorseleinApp.selfScroll = function ()
     });
 };
 
+PorseleinApp.loaded = function()
+{
+    $('.content_wrapper').show();
+    $('#spinner').hide();
+}
+
+PorseleinApp.loader = function ()
+{
+    $(window).load(PorseleinApp.loaded);
+}
+
+PorseleinApp.closeLightbox = function ()
+{
+    mediaShow.stopAllVideos();
+    $(".lightbox").hide();
+}
+
+PorseleinApp.openLightbox = function ()
+{
+    var videolead = $('.videolead');
+    if (videolead.length > 0)
+    {
+        var classes = $(videolead[0]).attr('class');
+        var uid = classes.substring(classes.indexOf('uid_')+4);
+        var slideshow = mediaShow.slideshows[0];
+        var i = mediaShow.idToIndex(slideshow, uid);
+        mediaShow.goToSlide(i, slideshow);
+    }
+    $(".lightbox").show();
+}
+
 $(function(){
+    PorseleinApp.loader();
     PorseleinApp.fixLinks();
     PorseleinApp.stopBounce();
     //PorseleinApp.selfScroll();
@@ -183,6 +215,29 @@ $(function(){
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 // Temporary stuff
 //=================================
 
